@@ -7,16 +7,18 @@ use Aspect::AdviceContext  ();
 use Aspect::Advice::After  ();
 use Aspect::Advice::Before ();
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 sub new {
 	my $class = "Aspect::Advice::" . ucfirst($_[1]); # Yes, a bit hacky
 	my $self  = $class->new(
-		hooks    => undef, # List of symbol table hooks
-		code     => $_[2], # the advice code
-		pointcut => $_[3], # the advice pointcut
+		code     => $_[2], # The advice code
+		pointcut => $_[3], # The advice pointcut
 	);
-	$self->install;
+
+	# Install and save the lexical hook
+	$self->{hook} = $self->install;
+
 	return $self;
 }
 
@@ -26,10 +28,6 @@ sub install {
 	die("Method 'install' is not implemented by " . ref($_[0]));
 }
 
-sub add_hooks {
-	push @{shift->{hooks}}, shift;
-}
-
 sub type {
 	die("Method 'type' is not implemented by " . ref($_[0]));
 }
